@@ -10,7 +10,7 @@ requires qw( experimental format );
 # Load time and dependencies negate execution time
 # use namespace::clean -except => 'meta';
 
-our $VERSION = '0.26';
+our $VERSION = '0.28';
 use Carp;
 
 #######
@@ -93,7 +93,7 @@ __END__
 
 =pod
 
-=encoding utf8
+=encoding UTF-8
 
 =head1 NAME
 
@@ -101,7 +101,7 @@ App::Midgen::Role::Attributes - Package Attributes used by L<App::Midgen>
 
 =head1 VERSION
 
-version: 0.26
+version: 0.28
 
 =head1 METHODS
 
@@ -145,6 +145,7 @@ See L<App::Midgen>
 
 =head1 LICENSE
 
-See L<App::Midgen>
+This library is free software; you can redistribute it and/or modify
+it under the same terms as Perl itself.
 
 =cut
