@@ -5,14 +5,14 @@ use Types::Standard qw( Bool );
 use Moo::Role;
 requires qw( ppi_document debug );
 
-our $VERSION = '0.26';
+our $VERSION = '0.28';
 use English qw( -no_match_vars );
 use version;
 use constant {TRUE => 1, FALSE => 0,};
 use Try::Tiny;
 
 has 'min_ver_fast' =>
-  (is => 'rw', isa => Bool, builder => '_build_min_ver_fast',);
+  (is => 'lazy', isa => Bool,);# builder => '_build_min_ver_fast',);
 
 sub _build_min_ver_fast {
   my $self = shift;
@@ -27,7 +27,7 @@ sub _build_min_ver_fast {
       return TRUE;
     }
   };
-  return;
+
 }
 
 #######
@@ -81,7 +81,7 @@ __END__
 
 =pod
 
-=encoding utf8
+=encoding UTF-8
 
 =head1 NAME
 
@@ -89,7 +89,7 @@ App::Midgen::Roles::FindMinVersion - used by L<App::Midgen>
 
 =head1 VERSION
 
-version: 0.26
+version: 0.28
 
 =head1 METHODS
 
@@ -129,7 +129,8 @@ See L<App::Midgen>
 
 =head1 LICENSE
 
-See L<App::Midgen>
+This library is free software; you can redistribute it and/or modify
+it under the same terms as Perl itself.
 
 =cut
 
