@@ -1,13 +1,14 @@
 package App::Midgen::Role::Options;
 
 use v5.10;
+
 use Types::Standard qw( Bool Int );
 use Moo::Role;
 
 # Load time and dependencies negate execution time
 # use namespace::clean -except => 'meta';
 
-our $VERSION = '0.26';
+our $VERSION = '0.28';
 use Carp;
 
 #######
@@ -49,7 +50,7 @@ has 'format' => (
 			dsl      => 1,
 			mi       => 1,
 			mb       => 1,
-			dzil     => 1,
+			eumm     => 1,
 			dist     => 1,
 			cpanfile => 1,
 			metajson => 1,
@@ -106,7 +107,7 @@ __END__
 
 =pod
 
-=encoding utf8
+=encoding UTF-8
 
 =head1 NAME
 
@@ -114,7 +115,7 @@ App::Midgen::Role::Options - Package Options used by L<App::Midgen>
 
 =head1 VERSION
 
-version: 0.26
+version: 0.28
 
 =head1 METHODS
 
@@ -166,6 +167,7 @@ See L<App::Midgen>
 
 =head1 LICENSE
 
-See L<App::Midgen>
+This library is free software; you can redistribute it and/or modify
+it under the same terms as Perl itself.
 
 =cut
