@@ -3,14 +3,14 @@ package App::Midgen::Role::Output;
 use v5.10;
 use Moo::Role;
 with qw(
+	App::Midgen::Role::Output::CPANfile
+	App::Midgen::Role::Output::Dist
+	App::Midgen::Role::Output::EUMM
+	App::Midgen::Role::Output::Infile
+	App::Midgen::Role::Output::MB
+	App::Midgen::Role::Output::METAjson
 	App::Midgen::Role::Output::MIdsl
 	App::Midgen::Role::Output::MI
-	App::Midgen::Role::Output::MB
-	App::Midgen::Role::Output::Dzil
-	App::Midgen::Role::Output::Dist
-	App::Midgen::Role::Output::CPANfile
-	App::Midgen::Role::Output::METAjson
-	App::Midgen::Role::Output::Infile
 );
 requires qw( format distribution_name get_module_version verbose );
 
@@ -20,7 +20,7 @@ no if $] > 5.017010, warnings => 'experimental::smartmatch';
 # Load time and dependencies negate execution time
 # use namespace::clean -except => 'meta';
 
-our $VERSION = '0.26';
+our $VERSION = '0.28';
 use English qw( -no_match_vars ); # Avoids reg-ex performance penalty
 local $OUTPUT_AUTOFLUSH = 1;
 
@@ -54,8 +54,8 @@ sub output_header {
 			) if not $self->quiet;
 
 		}
-		when ('dzil') {
-			$self->header_dzil( $self->distribution_name );
+		when ('eumm') {
+			$self->header_eumm( $self->distribution_name );
 		}
 		when ('mb') {
 			$self->header_mb( $self->distribution_name );
@@ -92,8 +92,8 @@ sub output_main_body {
 		when ('cpanfile') {
 			$self->body_cpanfile( $title, $required_ref );
 		}
-		when ('dzil') {
-			$self->body_dzil( $title, $required_ref );
+		when ('eumm') {
+			$self->body_eumm( $title, $required_ref );
 		}
 		when ('mb') {
 			$self->body_mb( $title, $required_ref );
@@ -129,8 +129,8 @@ sub output_footer {
 		when ('cpanfile') {
 			$self->footer_cpanfile( $self->distribution_name );
 		}
-		when ('dzil') {
-			$self->footer_dzil( $self->distribution_name );
+		when ('eumm') {
+			$self->footer_eumm( $self->distribution_name );
 		}
 		when ('mb') {
 			$self->footer_mb( $self->distribution_name );
@@ -174,7 +174,7 @@ __END__
 
 =pod
 
-=encoding utf8
+=encoding UTF-8
 
 =head1 NAME
 
@@ -182,7 +182,7 @@ App::Midgen::Role::Output - A collection of output orientated methods used by L<
 
 =head1 VERSION
 
-version: 0.26
+version: 0.28
 
 =head1 DESCRIPTION
 
@@ -227,7 +227,8 @@ See L<App::Midgen>
 
 =head1 LICENSE
 
-See L<App::Midgen>
+This library is free software; you can redistribute it and/or modify
+it under the same terms as Perl itself.
 
 =cut
 
