@@ -10,13 +10,13 @@ no if $] > 5.017010, warnings => 'experimental::smartmatch';
 # Load time and dependencies negate execution time
 # use namespace::clean -except => 'meta';
 
-our $VERSION = '0.26';
-use English qw( -no_match_vars ); # Avoids reg-ex performance penalty
+our $VERSION = '0.28';
+use English qw( -no_match_vars );    # Avoids reg-ex performance penalty
 local $OUTPUT_AUTOFLUSH = 1;
 
 use Term::ANSIColor qw( :constants colored );
-use Data::Printer { caller_info => 1, colored => 1, };
-use constant { BLANK => q{ }, NONE => q{}, THREE => 3, };
+use Data::Printer {caller_info => 1, colored => 1,};
+use constant {BLANK => q{ }, NONE => q{}, THREE => 3,};
 use File::Spec;
 
 #######
@@ -27,23 +27,23 @@ sub header_cpanfile {
 	my $package_name = shift // NONE;
 	my $mi_ver       = shift // NONE;
 
-	if ( $self->verbose > 0 ) {
-		print BRIGHT_BLACK "\n";
-		say '# Makefile.PL';
-		say 'use inc::Module::Install ' . $mi_ver . q{;};
-
-		$package_name =~ s{::}{-}g;
-		say "name '$package_name';";
-		say 'license \'perl\';';
-
-		$package_name =~ tr{-}{/};
-		say "version_from 'lib/$package_name.pm';";
-
-		print "\n";
-		say 'cpanfile;';
-		say 'WriteAll;';
-		print CLEAR "\n";
-	}
+#	if ( $self->verbose > 0 ) {
+#		print BRIGHT_BLACK "\n";
+#		say '# Makefile.PL';
+#		say 'use inc::Module::Install ' . $mi_ver . q{;};
+#
+#		$package_name =~ s{::}{-}g;
+#		say "name '$package_name';";
+#		say 'license \'perl\';';
+#
+#		$package_name =~ tr{-}{/};
+#		say "version_from 'lib/$package_name.pm';";
+#
+#		print "\n";
+#		say 'cpanfile;';
+#		say 'WriteAll;';
+#		print CLEAR "\n";
+#	}
 
 	return;
 }
@@ -56,54 +56,63 @@ sub body_cpanfile {
 	my $title        = shift;
 	my $required_ref = shift;
 
-	if ( $title eq 'requires' ) {
-		print "\n";
-
-		#		print BRIGHT_BLACK "\n";
-		#		say '# cpanfile';
-		#		print CLEAR;
-		say "requires 'perl', '$App::Midgen::Min_Version';";
-		print "\n";
-	}
-
-	#	print "\n";
-
 	my $pm_length = 0;
-	foreach my $module_name ( sort keys %{$required_ref} ) {
-		if ( length $module_name > $pm_length ) {
+	foreach my $module_name (sort keys %{$required_ref}) {
+		if (length $module_name > $pm_length) {
 			$pm_length = length $module_name;
 		}
 	}
 	given ($title) {
 		when ('requires') {
-			foreach my $module_name ( sort keys %{$required_ref} ) {
+			print "\n";
+
+			$required_ref->{'perl'} = $App::Midgen::Min_Version;
+			foreach my $module_name (sort keys %{$required_ref}) {
 
 				my $mod_name = "'$module_name',";
-				printf "%s %-*s '%s';\n", $title, $pm_length + THREE, $mod_name, $required_ref->{$module_name};
+				printf "%s %-*s '%s';\n", $title, $pm_length + THREE, $mod_name,
+					$required_ref->{$module_name}
+					if $required_ref->{$module_name} !~ m/mcpan/;
+			}
+		}
+		when ('runtime_recommends') {
+			print "\n";
+			foreach my $module_name (sort keys %{$required_ref}) {
+
+				my $mod_name = "'$module_name',";
+				printf "%s %-*s '%s';\n", 'recommends', $pm_length + THREE,
+					$mod_name, $required_ref->{$module_name}
+					if $required_ref->{$module_name} !~ m/mcpan/;
 			}
 		}
 		when ('test_requires') {
 			print "\n";
 			say 'on test => sub {';
-			foreach my $module_name ( sort keys %{$required_ref} ) {
+			foreach my $module_name (sort keys %{$required_ref}) {
 				my $mod_name = "'$module_name',";
-				printf "\t%s %-*s '%s';\n", 'requires', $pm_length + THREE, $mod_name, $required_ref->{$module_name};
+				printf "\t%s %-*s '%s';\n", 'requires', $pm_length + THREE,
+					$mod_name, $required_ref->{$module_name} if $required_ref->{$module_name} !~ m/mcpan/;
+
 			}
 			print "\n" if %{$required_ref};
 		}
 		when ('recommends') {
-			foreach my $module_name ( sort keys %{$required_ref} ) {
+			foreach my $module_name (sort keys %{$required_ref}) {
 				my $mod_name = "'$module_name',";
-				printf "\t%s %-*s '%s';\n", 'suggests', $pm_length + THREE, $mod_name, $required_ref->{$module_name};
+				printf "\t%s %-*s '%s';\n", 'suggests', $pm_length + THREE,
+					$mod_name, $required_ref->{$module_name} if $required_ref->{$module_name} !~ m/mcpan/;
+
 			}
 			say '};';
 		}
 		when ('test_develop') {
 			print "\n";
 			say 'on develop => sub {';
-			foreach my $module_name ( sort keys %{$required_ref} ) {
+			foreach my $module_name (sort keys %{$required_ref}) {
 				my $mod_name = "'$module_name',";
-				printf "\t%s %-*s '%s';\n", 'recommends', $pm_length + THREE, $mod_name, $required_ref->{$module_name};
+				printf "\t%s %-*s '%s';\n", 'recommends', $pm_length + THREE,
+					$mod_name, $required_ref->{$module_name} if $required_ref->{$module_name} !~ m/mcpan/;
+
 			}
 			say '};';
 		}
@@ -135,7 +144,7 @@ __END__
 
 =pod
 
-=encoding utf8
+=encoding UTF-8
 
 =head1 NAME
 
@@ -144,7 +153,7 @@ used by L<App::Midgen>
 
 =head1 VERSION
 
-version: 0.26
+version: 0.28
 
 =head1 DESCRIPTION
 
@@ -185,7 +194,8 @@ See L<App::Midgen>
 
 =head1 LICENSE
 
-See L<App::Midgen>
+This library is free software; you can redistribute it and/or modify
+it under the same terms as Perl itself.
 
 =cut
 
