@@ -1,5 +1,21 @@
 package App::Midgen::Role::Output::EUMM;
 
+use v5.10;
+use Moo::Role;
+requires qw( verbose );
+
+# turn off experimental warnings
+no if $] > 5.017010, warnings => 'experimental::smartmatch';
+
+# Load time and dependencies negate execution time
+# use namespace::clean -except => 'meta';
+
+our $VERSION = '0.28';
+use English qw( -no_match_vars );    # Avoids reg-ex performance penalty
+local $OUTPUT_AUTOFLUSH = 1;
+
+use Term::ANSIColor qw( :constants colored );
+use Data::Printer {caller_info => 1, colored => 1,};
 use constant {
 	BLANK  => q{ },
 	NONE   => q{},
@@ -8,20 +24,6 @@ use constant {
 	NINE   => q{         },
 	TWELVE => q{            },
 };
-
-use Moo::Role;
-requires qw( verbose );
-
-# Load time and dependencies negate execution time
-# use namespace::clean -except => 'meta';
-
-our $VERSION = '0.33_05';
-$VERSION = eval $VERSION;    ## no critic
-
-use English qw( -no_match_vars );    # Avoids reg-ex performance penalty
-local $OUTPUT_AUTOFLUSH = 1;
-
-use Term::ANSIColor qw( :constants colored );
 use File::Spec;
 
 #######
@@ -29,31 +31,33 @@ use File::Spec;
 #######
 sub header_eumm {
 	my $self = shift;
-	my $package_name = shift || NONE;
+	my $package_name = shift // NONE;
 
 	if ($package_name ne NONE) {
+		print "\n";
 
-		print "\nuse strict;\n";
-		print "use warnings;\n";
-		print "use ExtUtils::MakeMaker 6.68;\n\n";
+		say 'use strict;';
+		say 'use warnings;';
+		say 'use ExtUtils::MakeMaker 0.68;';
+		print "\n";
+		say 'WriteMakefile(';
 
-		print "WriteMakefile(\n";
-		print THREE. "'NAME' => '$package_name',\n";
+		say THREE. "'NAME' => '$package_name',";
 		$package_name =~ s{::}{/}g;
-		print THREE. "'VERSION_FROM' => 'lib/$package_name.pm',\n";
-		print THREE. "'ABSTRACT_FROM' => 'lib/$package_name.pm',\n";
+		say THREE. "'VERSION_FROM' => 'lib/$package_name.pm',";
+		say THREE. "'ABSTRACT_FROM' => 'lib/$package_name.pm',";
 
 		print BRIGHT_BLACK;
-		print THREE. "'AUTHOR' => '...',\n";
-		print THREE. "'LICENSE' => 'perl',\n";
+		say THREE. "'AUTHOR' => '...',";
+		say THREE. "'LICENSE' => 'perl_5',";
 		print CLEAR;
 ## 6.64 f***** RT#85406
-		print THREE. "'BUILD_REQUIRES' => {\n";
-		print SIX. "'ExtUtils::MakeMaker' => '6.68',\n";
-		print THREE. "},\n";
-		print THREE. "'CONFIGURE_REQUIRES' => {\n";
-		print SIX. "'ExtUtils::MakeMaker' => '6.68',\n";
-		print THREE. "},\n";
+		say THREE. "'BUILD_REQUIRES' => {";
+		say SIX. "'ExtUtils::MakeMaker' => '6.68'";
+		say THREE. "},";
+		say THREE. "'CONFIGURE_REQUIRES' => {";
+		say SIX. "'ExtUtils::MakeMaker' => '6.68'";
+		say THREE. "},";
 	}
 
 	return;
@@ -64,9 +68,7 @@ sub header_eumm {
 sub body_eumm {
 	my $self         = shift;
 	my $title        = shift;
-	my $required_ref = shift || return;
-
-	return if not %{$required_ref};
+	my $required_ref = shift;
 
 	my $pm_length = 0;
 	foreach my $module_name (sort keys %{$required_ref}) {
@@ -75,33 +77,24 @@ sub body_eumm {
 		}
 	}
 
-	print THREE. "'MIN_PERL_VERSION' => '$App::Midgen::Min_Version',\n"
-		if $title eq 'RuntimeRequires';
+	say THREE. "'MIN_PERL_VERSION' => '$App::Midgen::Min_Version',"
+		if $title eq 'requires';
 
-#	return if not %{$required_ref} and $title =~ m{(?:requires)\z};
+	return if not %{$required_ref} and $title =~ m{(?:requires)\z};
 
-	if ($title eq 'RuntimeRequires') {
-		print THREE. "'PREREQ_PM' => {\n";
-	}
-	elsif ($title eq 'TestRequires') {
-		print THREE. "'TEST_REQUIRES' => {\n";
-	}
-	elsif ($title eq 'recommends') {
-		$self->_recommends($required_ref);
-		return;
+	given ($title) {
+		when ('requires')      { say THREE. "'PREREQ_PM' => {"; }
+		when ('test_requires') { say THREE. "'TEST_REQUIRES' => {"; }
+		when ('recommends')    { $self->_recommends($required_ref); return; }
 	}
 
 	foreach my $module_name (sort keys %{$required_ref}) {
 
-		next
-			if $title eq 'TestRequires'
-			&& $required_ref->{$module_name} =~ m/mcpan/;
-
 		my $sq_key = q{'} . $module_name . q{'};
 		printf SIX. " %-*s => '%s',\n", $pm_length + 2, $sq_key,
 			$required_ref->{$module_name};
 	}
-	print THREE. "},\n";
+	say THREE. "},";
 
 	return;
 }
@@ -116,21 +109,21 @@ sub _recommends {
 			$pm_length = length $module_name;
 		}
 	}
-	print THREE. "'META_MERGE' => {\n";
-	print SIX. "'meta-spec' => { 'version' => '2' },\n";
+	say THREE. "'META_MERGE' => {";
+	say SIX. "'meta-spec' => { 'version' => '2' },";
 	return if not %{$required_ref};
-	print SIX. "'prereqs' => {\n";
-	print NINE. "'test' => {\n";
-	print TWELVE. "'suggests' => {\n";
+	say SIX. "'prereqs' => {";
+	say NINE. "'test' => {";
+	say TWELVE. "'suggests' => {";
 	foreach my $module_name (sort keys %{$required_ref}) {
 
 		my $sq_key = q{'} . $module_name . q{'};
 		printf "%-15s %-*s => '%s',\n", BLANK, $pm_length + 2, $sq_key,
 			$required_ref->{$module_name};
 	}
-	print TWELVE. "}\n";
-	print NINE. "}\n";
-	print SIX. "},\n";
+	say TWELVE. "}";
+	say NINE. "}";
+	say SIX. "},";
 
 }
 
@@ -140,49 +133,52 @@ sub _recommends {
 #######
 sub footer_eumm {
 	my $self = shift;
-	my $package_name = shift || NONE;
+	my $package_name = shift // NONE;
 	$package_name =~ s{::}{-}g;
 
 	if ($self->verbose > 0) {
 		print BRIGHT_BLACK;
 
-		print SIX. "'resources' => {\n";
+		say SIX. "'resources' => {";
 
-		print NINE. "'bugtracker' => {\n";
-		print TWELVE. "'web' => 'https://github.com/.../$package_name/issues',\n";
-		print NINE. "},\n";
+		say NINE. "'bugtracker' => {";
+		say TWELVE. "'web' => 'https://github.com/.../$package_name/issues',";
+		say NINE. "},";
 
-		print NINE. "'homepage' => 'https://github.com/.../$package_name',\n";
+		say NINE. "'homepage' => 'https://github.com/.../$package_name',";
 
-		print NINE. "'repository' => {\n";
-		print TWELVE. "'type' => 'git',\n";
-		print TWELVE. "'url' => 'git://github.com/.../$package_name.git',\n";
-		print TWELVE. "'web' => 'https://github.com/.../$package_name',\n";
-		print NINE. "},\n";
-		print SIX. "},\n";
+		say NINE. "'repository' => {";
+		say TWELVE. "'type' => 'git',";
+		say TWELVE. "'url' => 'git://github.com/.../$package_name.git',";
+		say TWELVE. "'web' => 'https://github.com/.../$package_name',";
+		say NINE. "},";
+		say SIX. "},";
 
-		print SIX. "'x_contributors' => [\n";
-		print NINE. "'brian d foy (ADOPTME) <brian.d.foy\@gmail.com>',\n";
-		print NINE. "'Fred Bloggs <fred\@bloggs.org>',\n";
-		print SIX. "],\n";
+		say SIX. "'x_contributors' => [";
+		say NINE. "'brian d foy (ADOPTME) <brian.d.foy\@gmail.com>',";
+		say NINE. "'Fred Bloggs <fred\@bloggs.org>',";
+		say SIX. "],";
 
 		print CLEAR;
-		print THREE. "},\n";
+		say THREE. '},';
 
 	}
 
+# todo sort out below
 	if (defined -d File::Spec->catdir($App::Midgen::Working_Dir, 'script')) {
-		print THREE. "'EXE_FILES' => [ (\n";
-		print SIX. "'script/...'\n";
-		print THREE. ") ],\n";
+		say THREE."'EXE_FILES' => [ (";
+		say SIX. "'script/...'";
+		say THREE.') ],';
+#		print "\n";
 	}
 	elsif (defined -d File::Spec->catdir($App::Midgen::Working_Dir, 'bin')) {
-		print THREE. "'EXE_FILES' => [qw(\n";
-		print SIX. "bin/...\n";
-		print THREE. ")],\n";
+		say THREE."'EXE_FILES' => [qw(";
+		say SIX. "bin/...";
+		say THREE.')],';
+#		print "\n";
 	}
 
-	print ")\n\n";
+	say ')'."\n";
 
 	return;
 }
@@ -204,7 +200,7 @@ used by L<App::Midgen>
 
 =head1 VERSION
 
-version: 0.33_05
+version: 0.28
 
 =head1 DESCRIPTION
 
