@@ -1,19 +1,18 @@
 package App::Midgen::Role::UseModule;
 
-use constant {BLANK => q{ }, TRUE => 1, FALSE => 0, NONE => q{}, TWO => 2,
-	THREE => 3,};
-
+use v5.10;
 use Moo::Role;
-requires
-	qw( ppi_document debug verbose format xtest _process_found_modules develop meta2 );
-
-our $VERSION = '0.33_05';
-$VERSION = eval $VERSION;    ## no critic
+requires qw( ppi_document debug format xtest _process_found_modules develop );
 
 use PPI;
-use Data::Printer {caller_info => 1,};
+
+use version 0.9902;
+use Data::Printer;    # caller_info => 1;
 use Try::Tiny;
-use Tie::Static qw(static);
+
+our $VERSION = '0.28';
+use constant {BLANK => q{ }, TRUE => 1, FALSE => 0, NONE => q{}, TWO => 2,
+	THREE => 3,};
 
 
 #######
@@ -21,7 +20,7 @@ use Tie::Static qw(static);
 #######
 sub xtests_use_module {
 	my $self = shift;
-	my $phase_relationship = shift || NONE;
+	my $storage_location = shift;
 
 	my @modules;
 	my @version_strings;
@@ -80,7 +79,7 @@ sub xtests_use_module {
 						)
 					{
 
-						for (0 .. $#{$chunk->{children}}) {
+						for ( 0..$#{$chunk->{children}}) {
 
 							# find all ppi_sl
 							if ($chunk->{children}[$_]->isa('PPI::Structure::List')) {
@@ -88,9 +87,8 @@ sub xtests_use_module {
 								my $ppi_sl = $chunk->{children}[$_]
 									if $chunk->{children}[$_]->isa('PPI::Structure::List');
 
-								print "Option 1: use_module( M::N )...\n" if $self->debug;
-								$self->_module_names_ppi_sl($ppi_sl, \@modules,
-									\@version_strings);
+								say 'Option 1: use_module( M::N )...' if $self->debug;
+								$self->_module_names_ppi_sl(\@modules, $ppi_sl);
 							}
 						}
 					}
@@ -156,7 +154,7 @@ sub xtests_use_module {
 					)
 					)
 				{
-					for (0 .. $#{$chunk->{children}}) {
+					for ( 0..$#{$chunk->{children}}) {
 
 						# find all ppi_sl
 						if ($chunk->{children}[$_]->isa('PPI::Structure::List')) {
@@ -164,11 +162,9 @@ sub xtests_use_module {
 							my $ppi_sl = $chunk->{children}[$_]
 								if $chunk->{children}[$_]->isa('PPI::Structure::List');
 
-							print "Option 2: my \$q = use_module( M::N )...\n"
-								if $self->debug;
-							$self->_module_names_ppi_sl($ppi_sl, \@modules,
-								\@version_strings);
-
+							say
+								'Option 2: my $q = use_module( M::N )...' if $self->debug;
+							$self->_module_names_ppi_sl(\@modules, $ppi_sl);
 
 						}
 					}
@@ -242,7 +238,7 @@ sub xtests_use_module {
 							)
 							)
 						{
-							for (0 .. $#{$chunk->{children}}) {
+							for ( 0..$#{$chunk->{children}}) {
 
 								# find all ppi_sl
 								if ($chunk->{children}[$_]->isa('PPI::Structure::List')) {
@@ -250,11 +246,9 @@ sub xtests_use_module {
 									my $ppi_sl = $chunk->{children}[$_]
 										if $chunk->{children}[$_]->isa('PPI::Structure::List');
 
-									print "Option 3: \$q = use_module( M::N )...\n"
-										if $self->debug;
-									$self->_module_names_ppi_sl($ppi_sl, \@modules,
-										\@version_strings);
-
+									say
+										'Option 3: $q = use_module( M::N )...' if $self->debug;
+									$self->_module_names_ppi_sl(\@modules, $ppi_sl);
 								}
 							}
 						}
@@ -339,17 +333,14 @@ sub xtests_use_module {
 					)
 					)
 				{
-					for (0 .. $#{$chunk->{children}}) {
+					for ( 0..$#{$chunk->{children}}) {
 
 						# find all ppi_sl
 						if ($chunk->{children}[$_]->isa('PPI::Structure::List')) {
 							my $ppi_sl = $chunk->{children}[$_]
 								if $chunk->{children}[$_]->isa('PPI::Structure::List');
-							print "Option 4: return use_module( M::N )...\n"
-								if $self->debug;
-							$self->_module_names_ppi_sl($ppi_sl, \@modules,
-								\@version_strings,);
-
+							say 'Option 4: return use_module( M::N )...' if $self->debug;
+							$self->_module_names_ppi_sl(\@modules, $ppi_sl);
 
 						}
 					}
@@ -358,24 +349,24 @@ sub xtests_use_module {
 		}
 	};
 
-#	p @version_strings;
-	@version_strings = map { defined $_ ? $_ : 0 } @version_strings;
-	p @modules         if $self->debug;
+	p @modules if $self->debug;
 	p @version_strings if $self->debug;
+
+	# if we found a module, process it with the correct catogery
 	if (scalar @modules > 0) {
+		if ($storage_location eq 'runtime_recommends') {
+			if ($self->format =~ /cpanfile|metajson/) {
+				$self->_process_found_modules('runtime_recommends', \@modules);
+
+			}
+			else {
+				$self->_process_found_modules('package_requires', \@modules);
+			}
 
-		for (0 .. $#modules) {
-			print "Info: UseModule -> Sending $modules[$_] - $version_strings[$_]\n"
-				if ($self->verbose == TWO);
-			try {
-				$self->_process_found_modules(
-					$phase_relationship, $modules[$_], $version_strings[$_],
-					__PACKAGE__,         $phase_relationship,
-				);
-			};
 		}
-	}
 
+#		$self->_process_found_modules('package_requires', \@modules);
+	}
 	return;
 }
 
@@ -419,25 +410,24 @@ sub _is_module_runtime {
 # composed method extract module name from PPI::Structure::List
 #######
 sub _module_names_ppi_sl {
-	my ($self, $ppi_sl, $mn_ref, $mv_ref) = @_;
+	my ($self, $modules, $ppi_sl) = @_;
 
 
 	if ($ppi_sl->isa('PPI::Structure::List')) {
 
-		static \my $previous_module;
+		state $previous_module = undef;
 		foreach my $ppi_se (@{$ppi_sl->{children}}) {
-			for (0 .. $#{$ppi_se->{children}}) {
+			for ( 0..$#{$ppi_se->{children}}) {
 
 				if ( $ppi_se->{children}[$_]->isa('PPI::Token::Quote::Single')
 					|| $ppi_se->{children}[$_]->isa('PPI::Token::Quote::Double'))
 				{
 					my $module = $ppi_se->{children}[$_]->content;
 					$module =~ s/(?:['|"])//g;
-					if ($module =~ m{\A(?:[a-zA-Z])}) {
-						print "found module - $module\n" if $self->debug;
-						push @{$mn_ref}, $module;
-						$mv_ref->[$#{$mn_ref}] = undef;
-						p @{$mn_ref} if $self->debug;
+					if ($module =~ m/\A[A-Z]/) {
+						warn 'found module - ' . $module if $self->debug;
+						push @$modules, $module;
+						p @$modules if $self->debug;
 						$previous_module = $module;
 					}
 				}
@@ -448,19 +438,20 @@ sub _module_names_ppi_sl {
 				{
 					my $version_string = $ppi_se->{children}[$_]->content;
 					$version_string =~ s/(?:['|"])//g;
-					next if $version_string !~ m{\A[\d|v]};
+					next if $version_string !~ m/\A[\d|v]/;
 
-					$version_string
-						= version::is_lax($version_string) ? $version_string : 0;
-
-					print "Info: UseModule found version_string - $version_string\n"
-						if $self->debug;
 
 					try {
-						if ($previous_module) {
-							$self->{found_version}{$previous_module} = $version_string;
-							$mv_ref->[$#{$mn_ref}] = $version_string;
-						}
+						version->parse($version_string)->is_lax;
+					}
+					catch {
+						$version_string = 0 if $_;
+					};
+
+					warn 'found version_string - ' . $version_string if $self->debug;
+					try {
+						$self->{found_version}{$previous_module}
+							= $version_string if $previous_module;
 						p $version_string if $self->debug;
 						$previous_module = undef;
 					};
@@ -468,6 +459,8 @@ sub _module_names_ppi_sl {
 			}
 		}
 	}
+
+
 }
 
 
@@ -488,7 +481,7 @@ includes, used by L<App::Midgen>
 
 =head1 VERSION
 
-version: 0.33_05
+version: 0.28
 
 
 =head1 METHODS
